==> allegro-5.0.0-i486-1sl.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf liballegro_primitives.so.5.0 )
( cd usr/lib ; ln -sf liballegro_primitives.so.5.0.0 liballegro_primitives.so.5.0 )
( cd usr/lib ; rm -rf liballegro_primitives.so )
( cd usr/lib ; ln -sf liballegro_primitives.so.5.0 liballegro_primitives.so )
( cd usr/lib ; rm -rf liballegro_main.so )
( cd usr/lib ; ln -sf liballegro_main.so.5.0 liballegro_main.so )
( cd usr/lib ; rm -rf liballegro_image.so )
( cd usr/lib ; ln -sf liballegro_image.so.5.0 liballegro_image.so )
( cd usr/lib ; rm -rf liballegro_color.so.5.0 )
( cd usr/lib ; ln -sf liballegro_color.so.5.0.0 liballegro_color.so.5.0 )
( cd usr/lib ; rm -rf liballegro_dialog.so )
( cd usr/lib ; ln -sf liballegro_dialog.so.5.0 liballegro_dialog.so )
( cd usr/lib ; rm -rf liballegro_font.so )
( cd usr/lib ; ln -sf liballegro_font.so.5.0 liballegro_font.so )
( cd usr/lib ; rm -rf liballegro_memfile.so )
( cd usr/lib ; ln -sf liballegro_memfile.so.5.0 liballegro_memfile.so )
( cd usr/lib ; rm -rf liballegro_dialog.so.5.0 )
( cd usr/lib ; ln -sf liballegro_dialog.so.5.0.0 liballegro_dialog.so.5.0 )
( cd usr/lib ; rm -rf liballegro_ttf.so.5.0 )
( cd usr/lib ; ln -sf liballegro_ttf.so.5.0.0 liballegro_ttf.so.5.0 )
( cd usr/lib ; rm -rf liballegro_image.so.5.0 )
( cd usr/lib ; ln -sf liballegro_image.so.5.0.0 liballegro_image.so.5.0 )
( cd usr/lib ; rm -rf liballegro_audio.so.5.0 )
( cd usr/lib ; ln -sf liballegro_audio.so.5.0.0 liballegro_audio.so.5.0 )
( cd usr/lib ; rm -rf liballegro.so.5.0 )
( cd usr/lib ; ln -sf liballegro.so.5.0.0 liballegro.so.5.0 )
( cd usr/lib ; rm -rf liballegro_main.so.5.0 )
( cd usr/lib ; ln -sf liballegro_main.so.5.0.0 liballegro_main.so.5.0 )
( cd usr/lib ; rm -rf liballegro.so )
( cd usr/lib ; ln -sf liballegro.so.5.0 liballegro.so )
( cd usr/lib ; rm -rf liballegro_color.so )
( cd usr/lib ; ln -sf liballegro_color.so.5.0 liballegro_color.so )
( cd usr/lib ; rm -rf liballegro_acodec.so.5.0 )
( cd usr/lib ; ln -sf liballegro_acodec.so.5.0.0 liballegro_acodec.so.5.0 )
( cd usr/lib ; rm -rf liballegro_memfile.so.5.0 )
( cd usr/lib ; ln -sf liballegro_memfile.so.5.0.0 liballegro_memfile.so.5.0 )
( cd usr/lib ; rm -rf liballegro_ttf.so )
( cd usr/lib ; ln -sf liballegro_ttf.so.5.0 liballegro_ttf.so )
( cd usr/lib ; rm -rf liballegro_audio.so )
( cd usr/lib ; ln -sf liballegro_audio.so.5.0 liballegro_audio.so )
( cd usr/lib ; rm -rf liballegro_acodec.so )
( cd usr/lib ; ln -sf liballegro_acodec.so.5.0 liballegro_acodec.so )
( cd usr/lib ; rm -rf liballegro_font.so.5.0 )
( cd usr/lib ; ln -sf liballegro_font.so.5.0.0 liballegro_font.so.5.0 )
( cd usr/lib ; rm -rf liballegro_physfs.so.5.0 )
( cd usr/lib ; ln -sf liballegro_physfs.so.5.0.0 liballegro_physfs.so.5.0 )
( cd usr/lib ; rm -rf liballegro_physfs.so )
( cd usr/lib ; ln -sf liballegro_physfs.so.5.0 liballegro_physfs.so )

==> allegro-5.0.2.1-i486-1sl.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf liballegro_color.so.5.0 )
( cd usr/lib ; ln -sf liballegro_color.so.5.0.2 liballegro_color.so.5.0 )
( cd usr/lib ; rm -rf liballegro_acodec.so )
( cd usr/lib ; ln -sf liballegro_acodec.so.5.0 liballegro_acodec.so )
( cd usr/lib ; rm -rf liballegro_physfs.so )
( cd usr/lib ; ln -sf liballegro_physfs.so.5.0 liballegro_physfs.so )
( cd usr/lib ; rm -rf liballegro_physfs.so.5.0 )
( cd usr/lib ; ln -sf liballegro_physfs.so.5.0.2 liballegro_physfs.so.5.0 )
( cd usr/lib ; rm -rf liballegro_primitives.so.5.0 )
( cd usr/lib ; ln -sf liballegro_primitives.so.5.0.2 liballegro_primitives.so.5.0 )
( cd usr/lib ; rm -rf liballegro_dialog.so.5.0 )
( cd usr/lib ; ln -sf liballegro_dialog.so.5.0.2 liballegro_dialog.so.5.0 )
( cd usr/lib ; rm -rf liballegro_font.so.5.0 )
( cd usr/lib ; ln -sf liballegro_font.so.5.0.2 liballegro_font.so.5.0 )
( cd usr/lib ; rm -rf liballegro_image.so )
( cd usr/lib ; ln -sf liballegro_image.so.5.0 liballegro_image.so )
( cd usr/lib ; rm -rf liballegro_memfile.so )
( cd usr/lib ; ln -sf liballegro_memfile.so.5.0 liballegro_memfile.so )
( cd usr/lib ; rm -rf liballegro_acodec.so.5.0 )
( cd usr/lib ; ln -sf liballegro_acodec.so.5.0.2 liballegro_acodec.so.5.0 )
( cd usr/lib ; rm -rf liballegro_dialog.so )
( cd usr/lib ; ln -sf liballegro_dialog.so.5.0 liballegro_dialog.so )
( cd usr/lib ; rm -rf liballegro_color.so )
( cd usr/lib ; ln -sf liballegro_color.so.5.0 liballegro_color.so )
( cd usr/lib ; rm -rf liballegro_font.so )
( cd usr/lib ; ln -sf liballegro_font.so.5.0 liballegro_font.so )
( cd usr/lib ; rm -rf liballegro_audio.so )
( cd usr/lib ; ln -sf liballegro_audio.so.5.0 liballegro_audio.so )
( cd usr/lib ; rm -rf liballegro_image.so.5.0 )
( cd usr/lib ; ln -sf liballegro_image.so.5.0.2 liballegro_image.so.5.0 )
( cd usr/lib ; rm -rf liballegro_main.so.5.0 )
( cd usr/lib ; ln -sf liballegro_main.so.5.0.2 liballegro_main.so.5.0 )
( cd usr/lib ; rm -rf liballegro.so.5.0 )
( cd usr/lib ; ln -sf liballegro.so.5.0.2 liballegro.so.5.0 )
( cd usr/lib ; rm -rf liballegro_ttf.so )
( cd usr/lib ; ln -sf liballegro_ttf.so.5.0 liballegro_ttf.so )
( cd usr/lib ; rm -rf liballegro_primitives.so )
( cd usr/lib ; ln -sf liballegro_primitives.so.5.0 liballegro_primitives.so )
( cd usr/lib ; rm -rf liballegro_ttf.so.5.0 )
( cd usr/lib ; ln -sf liballegro_ttf.so.5.0.2 liballegro_ttf.so.5.0 )
( cd usr/lib ; rm -rf liballegro.so )
( cd usr/lib ; ln -sf liballegro.so.5.0 liballegro.so )
( cd usr/lib ; rm -rf liballegro_audio.so.5.0 )
( cd usr/lib ; ln -sf liballegro_audio.so.5.0.2 liballegro_audio.so.5.0 )
( cd usr/lib ; rm -rf liballegro_main.so )
( cd usr/lib ; ln -sf liballegro_main.so.5.0 liballegro_main.so )
( cd usr/lib ; rm -rf liballegro_memfile.so.5.0 )
( cd usr/lib ; ln -sf liballegro_memfile.so.5.0.2 liballegro_memfile.so.5.0 )
